#
# spec file for package kinfocenter5
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports
%global __requires_exclude qmlimport\\(org\\.kde\\.kinfocenter.*

%global kf5_version 5.58.0

%bcond_without released
Name:           kinfocenter5
Version:        5.24.4
Release:        bp154.1.23
# Full Plasma 5 version (e.g. 5.8.95)
%{!?_plasma5_bugfix: %define _plasma5_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF5, but 5.8.95 in KUF)
%{!?_plasma5_version: %define _plasma5_version %(echo %{_plasma5_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        Utility that provides information about a computer system
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org/
Source:         https://download.kde.org/stable/plasma/%{version}/kinfocenter-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/kinfocenter-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
# PATCH-FIX-OPENSUSE
Patch100:       0002-Look-for-binaries-in-Mesa-demos-path-as-well.patch
BuildRequires:  extra-cmake-modules >= %{kf5_version}
BuildRequires:  systemsettings5
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  cmake(KF5Config) >= %{kf5_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5Declarative) >= %{kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5IconThemes) >= %{kf5_version}
BuildRequires:  cmake(KF5KCMUtils) >= %{kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{kf5_version}
BuildRequires:  cmake(KF5Package) >= %{kf5_version}
BuildRequires:  cmake(KF5Service) >= %{kf5_version}
BuildRequires:  cmake(KF5Solid) >= %{kf5_version}
BuildRequires:  cmake(KF5WidgetsAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5XmlGui) >= %{kf5_version}
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(libusb-1.0)
Conflicts:      kdebase4-workspace < 5.3.0
Recommends:     %{name}-lang
# needed for the fileindexermonitor
Requires:       baloo5-imports
# The executable is now a link to systemsettings5
Requires:       systemsettings5
# lspci is called by the PCI KCM
Requires:       pciutils
# GLX is always present
Requires:       /usr/bin/glxinfo
# Vulkan might not be needed
Requires:       (/usr/bin/vulkaninfo if libvulkan1)
# Plasma Wayland and X11 sessions are always installed
Requires:       /usr/bin/wayland-info
Requires:       /usr/bin/xdpyinfo
# Note: Not available as /usr/bin/eglinfo yet (boo#1195695)
Recommends:     /usr/bin/eglinfo
# Mesa-demos includes it, but as a whole it's too fat,
# so don't pull it in by default.
Suggests:       Mesa-demo

%description
KDE Utility that provides information about a computer system.

%lang_package

%prep
%autosetup -p1 -n kinfocenter-%{version}

%build
  %cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
  %cmake_build

%install
  %kf5_makeinstall -C build
%if %{with released}
  %kf5_find_lang
  %kf5_find_htmldocs
%endif

%files
%license LICENSES/*.txt
%{_kf5_bindir}/kinfocenter
%{_kf5_libdir}/libKInfoCenterInternal.so
%dir %{_kf5_plugindir}/
%dir %{_kf5_plugindir}/plasma/
%dir %{_kf5_plugindir}/plasma/kcms/
%{_kf5_plugindir}/plasma/kcms/kcm_about-distro.so
%{_kf5_plugindir}/plasma/kcms/kcm_energyinfo.so
%dir %{_kf5_plugindir}/plasma/kcms/kinfocenter/
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_cpu.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_devinfo.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_egl.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_glx.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_interrupts.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_nic.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_pci.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_samba.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_usb.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_vulkan.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_wayland.so
%{_kf5_plugindir}/plasma/kcms/kinfocenter/kcm_xserver.so
%{_kf5_applicationsdir}/org.kde.kinfocenter.desktop
%dir %{_kf5_htmldir}
%dir %{_kf5_htmldir}/en/
%doc %{_kf5_htmldir}/en/kinfocenter/
%{_kf5_sharedir}/kpackage/
%dir %{_kf5_sharedir}/kinfocenter/
%{_kf5_sharedir}/kinfocenter/categories/
%{_kf5_servicetypesdir}/
%{_kf5_configdir}/menus/kinfocenter.menu
%{_kf5_sharedir}/desktop-directories/
%{_kf5_appstreamdir}/org.kde.kinfocenter.appdata.xml
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%{_kf5_qmldir}/org/kde/kinfocenter/

%if %{with released}
%files lang -f %{name}.lang
%endif

%changelog
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- Changes since 5.24.2:
  * fix up help paths (kde#450918)
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- Changes since 5.24.0:
  * Search in /usr/local/sbin:/usr/sbin:/sbin as fallback (kde#449792)
- Drop patches, now upstream
  * 0001-Search-in-usr-local-sbin-usr-sbin-sbin-as-fallback.patch
* Wed Feb  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Change patch to also search in /sbin:
  * Add 0001-Search-in-usr-local-sbin-usr-sbin-sbin-as-fallback.patch
  * Drop 0001-Search-in-usr-local-sbin-usr-sbin-as-fallback.patch
  * Rebase 0002-Look-for-binaries-in-Mesa-demos-path-as-well.patch
* Tue Feb  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to actually find lscpi (kde#449792, boo#1195696):
  * 0001-Search-in-usr-local-sbin-usr-sbin-as-fallback.patch
- ... and eglinfo (boo1195695):
  * 0002-Look-for-binaries-in-Mesa-demos-path-as-well.patch
- Suggest Mesa-demo for eglinfo
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * Drop unnecessary KIconThemes dependency
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Too many changes to list here
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * fix up about-distro exec
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Too many changes to list here
- Drop patches, now upstream:
  * 0001-Handle-libpci-errors-gracefully.patch
  * 0002-Enable-the-PCI-module-everywhere.patch
- Drop patch, now longer necessary:
  * plasma-session-name.patch
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- Changes since 5.22.3:
  * unbreak about CPU value when solid is missing a product string (kde#439464)
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- Changes since 5.22.2.1:
  * remove cell dimension setting
  * unbreak the refresh button
  * disable layout twinning in NIC kcm
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Thu Jun 17 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to enable the PCI module on ARM:
  * 0001-Handle-libpci-errors-gracefully.patch
  * 0002-Enable-the-PCI-module-everywhere.patch
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Mon Jun 14 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add missing pkgconfig(libusb-1.0) BuildRequires (boo#1187319)
- Mention all KCMs in %%files explicitly
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- No code changes since 5.21.90
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Too many changes to list here
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- No code changes since 5.21.4
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- No code changes since 5.21.3
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- Changes since 5.21.2:
  * force-resize columns in the wayland module (kde#433327)
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- No code changes since 5.21.0
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * About-distro: display Graphics Platform (X11 or Wayland) (kde#428382)
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Changes since 5.20.5:
  * Port away from QRegExp
  * typo--
  * Remove unused includes
  * weight main categories properly (kde#429153)
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Now it depends against new version. Old code can be removed
  * Remove not implemented method
  * Use more correct factory name
  * Fix SolDevice null pointer dereference
  * Update device info on selection change instead of activation
  * There is no need for static local variables
  * Documentation fixes
  * Use correct name for new Samba Status module
  * port samba module to qml
  * Fix minor typos
  * [modules/nics] Use consistent name everywhere
  * Port nic info center module to QML
* Sat Jan  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add support for qml-autoreqprov
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- No code changes since 5.20.4
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- Changes since 5.20.3:
  * weight main categories properly (kde#429153)
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- No code changes since 5.20.2
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- No code changes since 5.20.1
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- No code changes since 5.20.0
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- No code changes since 5.19.90
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Changes since 5.19.5:
  * Remove explicit ECM_KDE_MODULE_DIR
  * drop qt3 support defs
  * set more screenshots
  * switch Exec line to kinfocenter
  * correct appstream homepage URL to plasma homepage
  * Use camelcase (scripted)
  * Add README
  * Add device "Description" to sidebar
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- No code changes since 5.19.4
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- No code changes since 5.19.3
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- No code changes since 5.19.2
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- Changes since 5.19.1:
  * also localize the bit entry
  * make entry members protected
  * Fix English copy to clipboard version (kde#407179)
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- Changes since 5.19.0:
  * Address trailing newline and spaces (kde#422968)
  * usb: parse version from sysfs entries correctly (kde#422610)
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- No code changes since 5.18.90
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Changes since 5.18.5:
  * use better strings for dri devices
  * bump to require Qt 5.14
  * view1394: initialize OuiDb only when needed
  * view1394: try to load OUI data from system location
  * view1394: isolate DB loading in own function
  * Optimize message extraction
  * don't hold initdness in a static var (kde#417466)
  * improve some previously recycled strings
  * add gpu entry to about system (kde#355053)
  * refactor about-distro to more generically support textual dumps
  * cleanup devinfo header includes
  * add trivial systemsettings finder and mark it as RUNTIME dep
  * Restore config-x11 header file
  * Kill the KinfoCenter binary
  * Remove unused includes
- Refresh patches:
  * plasma-session-name.patch
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- Changes since 5.18.4.1:
  * adjust smb kcm size to be sufficient vis a vis headers (kde#419786)
  * strip non printable characters from opengl dri info
  * make opengl module support multiple dri devices (kde#417986)
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- Changes since 5.18.3:
  * only add devices to the smb mount model that are network shares
  * skip over supposed network shares that aren't
  * Be more accurate in reporting the x86 CPU features solid detects
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- No code changes since 5.18.2
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- No code changes since 5.18.1
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- Changes since 5.18.0:
  * make sure ifa_addr isn't null (kde#417798)
  * appdata: fix <lanchable>
  * import currently used license copies for reuse compliance
  * replace samba module with data that works (kde#411433,kde#374141,kde#325951)
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- Changes since 5.17.90:
  * fix var name in sa_len branch
  * do not disable getifaddrs use because of sa_len availablility (kde#313892,kde#277208)
  * remove all platform conditionals not pertaining to linux or *bsd
  * one feature_summary call (in the main file) is enough thank you very much
  * tooltipmanager: use qstyle wakeup delay instead of hardcoding (kde#393722)
  * override picutils' error logger; it has an exit() call (kde#382979)
  * parse xorg version for nicer display (kde#344038)
  * do not show "copy in english" when using C as locale (kde#403368)
  * find org.kde.kirigami as runtime dependency (kde#403011)
  * do not needlessly run through Solid::Device::allDevices (kde#399746)
  * remove uselss boilerplate line
  * make sure Solid::Battery is not deleted from QML (kde#413003)
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * KF5_MIN_VERSION for plasma 5.18 is KF5 5.66.0
  * Fix compile without deprecated methods
  * Port away from deprecated KIconLoader::SmallIcon
  * Fix link: ui.html -> menus.html
  * Use URL with transport encryption
  * Add missing override
  * This method is never used (and use a deprecated methods)
  * Add KDEClangFormat cmake support
  * [energy kcm] Fix Technology values
  * [energy KCM] Add battery Technology
  * Port some deprecated methods
  * Port QLayout::setMargins
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- No code changes since 5.17.4
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- No code changes since 5.17.3
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- No code changes since 5.17.0
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- No code changes since 5.16.90
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Too many changes to list here
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- No code changes since 5.16.4
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- No code changes since 5.16.2
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- Changes since 5.16.0:
  * Update default Samba log path
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- No code changes since 5.15.90
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
  * drop internal os-release class in favor of KOSRelease of kcoreaddons 5.58
  * extends keywords of device info module
  * Add appstream data
  * Correctly show memory sizes > 4 GiB on 32 bit Linux (kde#406351)
  * [about-distro] OSRelease to collect "extra" keys
  * [about-distro] pimpl OSRelease privates
  * Fix initial width/height in KCMs that use qml (kde#398820)
  * color monochrome icons to tooltip colors
  * remove deprecated methods
- Drop patches, now upstream:
  * Correctly-show-mem-size-over-4GiB-on-32bit.patch
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- No code changes since 5.15.4
* Tue Apr 30 2019 wbauer@tmo.at
- Add Correctly-show-mem-size-over-4GiB-on-32bit.patch to fix wrong
  display of RAM size on a 32bit system if there is more than 4 GiB
  (boo#1131826, kde#406351)
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- Changes since 5.15.3:
  * Clean up generated config-*.h files
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- Changes since 5.15.2:
  * style++
  * connect clicked signal of view (again) (kde#405373)
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- Changes since 5.15.1:
  * only enable the module help button if the module actually has help
  * unbreak help button activation by not double-resetting the view (kde#392597)
  * [about-distro] let distributions choose VERSION_ID or VERSION
  * [about-distro] run logo lookup via osrelease
  * [about-distro] run variant through os-release
  * [about-distro] update osrelease parser for latest values in spec
  * [about-distro] run absolute paths through qicon intead of qpixmap
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- No code changes since 5.14.90
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * Fix USB view (kde#402949)
  * Consti'fy
  * remove some clazy warning
  * Update logic for disabling the PCI module.
  * Copy to Clipboard in English
  * We depend against kf5 5.50
  * Fix mem leak found by asan
  * Copy to clipboard: match item order of copied text with GUI (kde#400732)
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * Increase default window size so nothing gets cut off by default BUG: 364767 FIXED-IN: 5.12.8 (kde#364767)
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- No code changes since 5.14.3
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- Changes since 5.13.90:
  * Use QtQuick.Controls 2.0 Label in energy and fileindexmonitor KCM
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * QT_MIN_VERSIONS is Qt 5.11 for Plasma 5.14. Agreed at kickoff meeting.  Set everywhere for clearity and consistency.
  * Add "Copy Info" button to the About System KCM (kde#366266)
  * Fix minor EBN issues
  * Move "update" button from the left side to the right side in NIC module
  * Add QStringLiteral when necessary
  * increase version as for other apps
  * Warning--
  * Use QStringLiteral where it's possible
  * Implement sorting of the device tree items (kde#380355)
  * Do not duplicate work of KAboutData::setupCommandLine()
  * Fix wrong full form of acronym SMB in kinfocenter docbook
  * Improve single-instance application behavior
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * Fix file indexer monitor Exec line (kde#396977)
  * Update kinfocenter docbook to 5.12
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * None
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * None
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * kcm_opengl: Fix retrieval of DRI information
  * kcm_opengl: Fix EGL info retrieval.
  * Fix displaying OpenGL info on wayland: do not require OpenGL 3.2
  * Update kinfocenter docbook to 5.12
  * [Device Viewer] Add battery percentage bar
  * [Device Viewer] Add missing Solid battery types
  * Remove unused X-Plasma-RemoteLocation entries
  * Remove not necessary QtCore and co
  * Remove long-time deprecated Encoding=UTF-8 from desktop format files
  * Show high-resolution and vector logos properly in HighDPI mode (kde#388633)
  * Don't use const'ref for int element
  * Remove unused definition
- Remove patches, now upstream:
  * kcm_opengl-Fix-retrieval-of-DRI-information.patch
* Tue May  8 2018 wbauer@tmo.at
- Add kcm_opengl-Fix-retrieval-of-DRI-information.patch to fix
  displaying 3D acceleration info and kernel module in "OpenGL"
  with kernels >= 3.12
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * kcm_opengl: Fix EGL info retrieval.
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * kcm_energyinfo: Allow changing of the timespan if no data available
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * None
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Ensure Registry gets destroyed before the Wayland connection (kde#387479)
  * Show high-resolution and vector logos properly in HighDPI mode (kde#388633)
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * None
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Const'ify, initialize variable, minor optimization
  * Update copyright
  * Fix cmake warning
  * Const'ify
  * When we click on "clear search" clear lineedit too
  * Do not leak XVisualInfo (GLX path)
  * Don't build pci module on ARM (kde#335908)
  * Remove obsolete reviewboardrc file
  * const'ify
  * Use isEmpty
  * Port to new connect api
  * Port to new connect api
  * USe nullptr. Clean up. Optimization
  * Add gitignore
  * Reindent it
  * Make as explicit, use nullptr
  * Fix clazy warning
  * Fix some clazy warning
  * simplify check
  * Ise nullptr
  * Modernize code
  * opengl: Dummy string should not be translatable
  * Expose the memory usage percentages to accessibility tools
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * None
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * Drop custom app metadata setting, KAboutData::setApplicationData does it
  * Call KLocalizedString::setApplicationDomain before first i18n usage
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * Allow to select module with keyboard
  * Do not leak XVisualInfo (X11 EGL path)
  * Do not mark {variantLabel} as translatable
  * Use Q_DECL_OVERRIDE
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * None
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * None
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * None
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * Add output scale to Wayland overview
  * Port away from KDELibs4Support
  * Port tooltips to KToolTipWidget
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Wed Mar  1 2017 fabian@ritter-vogt.de
- Introduce and use kf5_version global
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * None
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * None
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * None
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * Fix battery charge state display. See kde#372081
  * Pass transient parent window to KToolTipWindow.
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Thu Nov  3 2016 fabian@ritter-vogt.de
- Introduce new _plasma5_bugfix global for more fine-tuned dependencies
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Use %%{_plasma5_version} again, define it if needed
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Sat Jan 23 2016 wbauer@tmo.at
- Require baloo5-imports, this is needed for the
  fileindexermonitor to work
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
- Drop upstreamed kinfocenter-fix-cmdline-parsing.patch
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Fri Oct 23 2015 alarrosa@suse.com
- Fix the command line parsing, which was crashing when
  calling kinfocenter --version
  * kinfocenter-fix-cmdline-parsing.patch
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Sat Jun 20 2015 anixx@opensuse.org
- remove explicit conflict with KDE3, there in no such file at
  this location in kdebase3
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Wed Apr 29 2015 hrvoje.senjan@gmail.com
- Added plasma-session-name.patch: we use plasma5.desktop for the
  session, not plasma.desktop; fixes missing version number in
  main kcm
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
- Only conflict with kdebase4-workspace < 5.3.0
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Added kdeclarative-devel and kpackage-devel BuildRequires
- Drop opensuse-kinfocenter.diff, no longer needed
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Set the correct version
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Sat Oct 25 2014 hrvoje.senjan@gmail.com
- Recommend lang subpackage
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Ported Wayland KCM to KWayland, instead of using Wayland directly
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
- Swap pkgconfig(wayland-client) for kwayland-devel >= 5.0.95
- Drop kwindowsystem-devel BuildRequires, no longer used
* Mon Aug 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Fri Jul 18 2014 hrvoje.senjan@gmail.com
- Added opensuse-kinfocenter.diff to have some openSUSE distro info
  in kinfocenter (backported from 4.11.x kdebase4-workspace package)
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
- Adjust BuildRequires depending whether Qt is built with openGL or open GL ES2
* Thu Jul 10 2014 hrvoje.senjan@gmail.com
- Install license
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Thu Jun 12 2014 hrvoje.senjan@gmail.com
- Activate kinfocenter5 package
